@@ -1,5 +1,5 @@
 # used to trigger commands indexing
-from . import add, blame, fetch, init, pull, storage, update  # noqa
+from . import add, blame, fetch, init, pull, storage  # noqa
 from .app import _app as app
 
 
