@@ -1,18 +1,17 @@
 import os
 import shutil
-import warnings
 from enum import Enum
 from pathlib import Path
 from typing import List, Optional
 
 import typer
 from rich.progress import track
+from typing_extensions import Annotated
 
 from ..exceptions import HashError
 from ..hash import from_hash, is_hash, to_hash
-from ..ops import Conflict, load_hash
-from .add import add
-from .app import _app, app_command, cli_error
+from ..ops import load_hash
+from .app import app_command, cli_error
 from .utils import normalize_sources, normalize_sources_and_destination
 
 
@@ -31,19 +30,23 @@ class PullMode(Enum):
 
 @app_command
 def pull(
-        sources: List[Path] = typer.Argument(..., help='The source paths to add', show_default=False),
-        mode: PullMode = typer.Option(..., help=PullMode.__doc__, show_default=False),
-        destination: Optional[Path] = typer.Option(
-            None, '--destination', '--dst',
+        sources: Annotated[List[Path], typer.Argument(help='The source paths to add', show_default=False)],
+        mode: Annotated[PullMode, typer.Option(help=PullMode.__doc__, show_default=False)],
+        destination: Annotated[Optional[Path], typer.Option(
+            '--destination', '--dst',
             help='The destination at which the results will be stored. '
                  'If none -  the results will be stored alongside the source'
-        ),
-        keep: bool = typer.Option(False, help='Whether to keep the sources after pulling the real files'),
-        fetch: bool = typer.Option(False, help='Whether to fetch the missing files from remote, if possible'),
-        repository: Path = typer.Option(
-            None, '--repository', '--repo', help='The bev repository. It is usually detected automatically',
+        )] = None,
+        keep: Annotated[bool, typer.Option(
+            help='Whether to keep the sources after pulling the real files'
+        )] = False,
+        fetch: Annotated[bool, typer.Option(
+            help='Whether to fetch the missing files from remote, if possible'
+        )] = True,
+        repository: Annotated[Path, typer.Option(
+            '--repository', '--repo', help='The bev repository. It is usually detected automatically',
             show_default=False,
-        )
+        )] = None
 ):
     """Restore the files and folders that were added to storage"""
 
@@ -131,19 +134,3 @@ PULL_MODES = {
     PullMode.copy: lambda h, dst, repo, fetch: repo.storage.read(shutil.copyfile, h, dst, fetch=fetch),
     PullMode.hash: save_hash,
 }
-
-
-@_app.command(deprecated=True)
-def gather(
-        source: Path = typer.Argument(..., help='The source path to gather', show_default=False),
-        destination: Optional[Path] = typer.Option(
-            None, '--destination', '--dst',
-            help='The destination at which the hashes will be stored. '
-                 'If none -  the hashes will be stored alongside the source'
-        ),
-):  # pragma: no cover
-    """Reverse a "pull" command. Warning! this command is superseded by "add" and will be removed soon"""
-
-    warnings.warn('This command is deprecated. Use "add" instead', UserWarning)
-    warnings.warn('This command is deprecated. Use "add" instead', DeprecationWarning)
-    return add([source], destination, False, Conflict.error, '.')
