@@ -1,8 +1,13 @@
+import importlib
 from typing import Optional, Type
 
 _REGISTRY = {}
 
 
+class RegistryError(Exception):
+    pass
+
+
 def register(name, cls: Optional[Type] = None):
     def decorator(kls: Type):
         if not isinstance(kls, type):
@@ -20,17 +25,26 @@ def register(name, cls: Optional[Type] = None):
 
         return kls
 
+    if '.' in name:
+        raise ValueError('Names with dots are reserved for references to modules')
     if cls is None:
         return decorator
     return decorator(cls)
 
 
-def find(kind: Type, name: str):
+def find(name: str, kind: Type):
+    if '.' in name:
+        module, name = name.rsplit('.', 1)
+        module = importlib.import_module(module)
+        value = getattr(module, name)
+        assert issubclass(value, kind), value
+        return value
+
     if kind not in _REGISTRY:
-        raise ValueError(f'{kind} not found')
+        raise RegistryError(f'{kind} not found')
     local = _REGISTRY[kind]
     if name not in local:
-        raise ValueError(f'Invalid key "{name}" for "{kind.__name__}"')
+        raise RegistryError(f'Invalid key "{name}" for "{kind.__name__}"')
 
     return local[name]
 
