@@ -1,8 +1,9 @@
 class LocalVersion:
     """A class used to denote the current uncommitted version of data"""
 
-    def __getstate__(self):  # pragma: no cover
-        raise RuntimeError('This object cannot be pickled')
+    @classmethod
+    def __getversion__(cls):
+        raise RuntimeError("The `Local` object doesn't have a well-defined version")
 
     def __eq__(self, other):
         return isinstance(other, LocalVersion)
